// Copyright (C) 2024  AstroGD® Lukas Weber
import allValuesBlock, { length as l1 } from "./allValuesBlock";
import allValuesColumn, { length as l2 } from "./allValuesColumn";
import allValuesRow, { length as l3 } from "./allValuesRow";
import atLeastOneValue, { length as l4 } from "./atLeastOneValue";
import fixedValuesHandler, { getLength as getL5 } from "./fixedValues";
import maxOneValue, { length as l6 } from "./maxOneValue";

export default function* generateRules(fixedValues: number[]): Generator<string, null, undefined> {
  const generators = [allValuesBlock(), allValuesColumn(), allValuesRow(), atLeastOneValue(), maxOneValue(), fixedValuesHandler(fixedValues)];

  for (const generator of generators) {
    let rule = generator.next().value;
    while (rule !== null) {
      yield rule.join(" ") + " 0";
      rule = generator.next().value;
    }
  }

  return null;
}

export function getLength(fixedValues: number[]): number {
  return l1 + l2 + l3 + l4 + getL5(fixedValues) + l6;
}
